@@ -1,9 +1,12 @@
 from graphene.contrib.django.types import (
+    DjangoConnection,
     DjangoObjectType,
-    DjangoInterface,
     DjangoNode
 )
 from graphene.contrib.django.fields import (
     DjangoConnectionField,
     DjangoModelField
 )
+
+__all__ = ['DjangoObjectType', 'DjangoNode', 'DjangoConnection',
+           'DjangoModelField', 'DjangoConnectionField']
